# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/instance_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.compute.v1 import disk_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2
from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/instance_service.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.yandex/cloud/compute/v1/instance_service.proto\x12\x17yandex.cloud.compute.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\"yandex/cloud/compute/v1/disk.proto\x1a&yandex/cloud/compute/v1/instance.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"l\n\x12GetInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x33\n\x04view\x18\x02 \x01(\x0e\x32%.yandex.cloud.compute.v1.InstanceView\"\x91\x01\n\x14ListInstancesRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"f\n\x15ListInstancesResponse\x12\x34\n\tinstances\x18\x01 \x03(\x0b\x32!.yandex.cloud.compute.v1.Instance\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xfb\n\n\x15\x43reateInstanceRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x32\n\x04name\x18\x02 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x93\x01\n\x06labels\x18\x04 \x03(\x0b\x32:.yandex.cloud.compute.v1.CreateInstanceRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x1d\n\x07zone_id\x18\x05 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\x0bplatform_id\x18\x06 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x44\n\x0eresources_spec\x18\x07 \x01(\x0b\x32&.yandex.cloud.compute.v1.ResourcesSpecB\x04\xe8\xc7\x31\x01\x12N\n\x08metadata\x18\x08 \x03(\x0b\x32<.yandex.cloud.compute.v1.CreateInstanceRequest.MetadataEntry\x12\x42\n\x10metadata_options\x18\x13 \x01(\x0b\x32(.yandex.cloud.compute.v1.MetadataOptions\x12G\n\x0e\x62oot_disk_spec\x18\t \x01(\x0b\x32).yandex.cloud.compute.v1.AttachedDiskSpecB\x04\xe8\xc7\x31\x01\x12P\n\x14secondary_disk_specs\x18\n \x03(\x0b\x32).yandex.cloud.compute.v1.AttachedDiskSpecB\x07\x82\xc8\x31\x03<=3\x12H\n\x10local_disk_specs\x18\x12 \x03(\x0b\x32..yandex.cloud.compute.v1.AttachedLocalDiskSpec\x12I\n\x10\x66ilesystem_specs\x18\x11 \x03(\x0b\x32/.yandex.cloud.compute.v1.AttachedFilesystemSpec\x12U\n\x17network_interface_specs\x18\x0b \x03(\x0b\x32-.yandex.cloud.compute.v1.NetworkInterfaceSpecB\x05\x82\xc8\x31\x01\x31\x12\x36\n\x08hostname\x18\x0c \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x44\n\x11scheduling_policy\x18\r \x01(\x0b\x32).yandex.cloud.compute.v1.SchedulingPolicy\x12\x1a\n\x12service_account_id\x18\x0e \x01(\t\x12\x42\n\x10network_settings\x18\x0f \x01(\x0b\x32(.yandex.cloud.compute.v1.NetworkSettings\x12:\n\x0cgpu_settings\x18\x14 \x01(\x0b\x32$.yandex.cloud.compute.v1.GpuSettings\x12\x42\n\x10placement_policy\x18\x10 \x01(\x0b\x32(.yandex.cloud.compute.v1.PlacementPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n\x16\x43reateInstanceMetadata\x12\x1d\n\x0binstance_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\"\x88\x07\n\x15UpdateInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x93\x01\n\x06labels\x18\x05 \x03(\x0b\x32:.yandex.cloud.compute.v1.UpdateInstanceRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x13\n\x0bplatform_id\x18\x06 \x01(\t\x12>\n\x0eresources_spec\x18\x07 \x01(\x0b\x32&.yandex.cloud.compute.v1.ResourcesSpec\x12N\n\x08metadata\x18\x08 \x03(\x0b\x32<.yandex.cloud.compute.v1.UpdateInstanceRequest.MetadataEntry\x12\x42\n\x10metadata_options\x18\r \x01(\x0b\x32(.yandex.cloud.compute.v1.MetadataOptions\x12\x1a\n\x12service_account_id\x18\t \x01(\t\x12\x42\n\x10network_settings\x18\n \x01(\x0b\x32(.yandex.cloud.compute.v1.NetworkSettings\x12\x42\n\x10placement_policy\x18\x0b \x01(\x0b\x32(.yandex.cloud.compute.v1.PlacementPolicy\x12\x44\n\x11scheduling_policy\x18\x0c \x01(\x0b\x32).yandex.cloud.compute.v1.SchedulingPolicy\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"-\n\x16UpdateInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\":\n\x15\x44\x65leteInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"-\n\x16\x44\x65leteInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"\xc7\x01\n\x1dUpdateInstanceMetadataRequest\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x03(\t\x12R\n\x06upsert\x18\x03 \x03(\x0b\x32\x42.yandex.cloud.compute.v1.UpdateInstanceMetadataRequest.UpsertEntry\x1a-\n\x0bUpsertEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x1eUpdateInstanceMetadataMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"b\n\"GetInstanceSerialPortOutputRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x19\n\x04port\x18\x02 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x31,2,3,4\"7\n#GetInstanceSerialPortOutputResponse\x12\x10\n\x08\x63ontents\x18\x01 \x01(\t\"8\n\x13StopInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"+\n\x14StopInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"9\n\x14StartInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\",\n\x15StartInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\";\n\x16RestartInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\".\n\x17RestartInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"\x8b\x01\n\x19\x41ttachInstanceDiskRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12K\n\x12\x61ttached_disk_spec\x18\x02 \x01(\x0b\x32).yandex.cloud.compute.v1.AttachedDiskSpecB\x04\xe8\xc7\x31\x01\"B\n\x1a\x41ttachInstanceDiskMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64isk_id\x18\x02 \x01(\t\"\x9a\x01\n\x19\x44\x65tachInstanceDiskRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1b\n\x07\x64isk_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12/\n\x0b\x64\x65vice_name\x18\x03 \x01(\tB\x18\xf2\xc7\x31\x14[a-z][a-z0-9-_]{,19}H\x00\x42\x0c\n\x04\x64isk\x12\x04\xc0\xc1\x31\x01\"B\n\x1a\x44\x65tachInstanceDiskMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x0f\n\x07\x64isk_id\x18\x02 \x01(\t\"\x9d\x01\n\x1f\x41ttachInstanceFilesystemRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12W\n\x18\x61ttached_filesystem_spec\x18\x02 \x01(\x0b\x32/.yandex.cloud.compute.v1.AttachedFilesystemSpecB\x04\xe8\xc7\x31\x01\"N\n AttachInstanceFilesystemMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x15\n\rfilesystem_id\x18\x02 \x01(\t\"\xac\x01\n\x1f\x44\x65tachInstanceFilesystemRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\rfilesystem_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12/\n\x0b\x64\x65vice_name\x18\x03 \x01(\tB\x18\xf2\xc7\x31\x14[a-z][a-z0-9-_]{,19}H\x00\x42\x12\n\nfilesystem\x12\x04\xc0\xc1\x31\x01\"N\n DetachInstanceFilesystemMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x15\n\rfilesystem_id\x18\x02 \x01(\t\"\xb6\x01\n\x1d\x41\x64\x64InstanceOneToOneNatRequest\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x1f\n\x17network_interface_index\x18\x02 \x01(\t\x12\x18\n\x10internal_address\x18\x03 \x01(\t\x12\x45\n\x13one_to_one_nat_spec\x18\x04 \x01(\x0b\x32(.yandex.cloud.compute.v1.OneToOneNatSpec\"5\n\x1e\x41\x64\x64InstanceOneToOneNatMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"r\n RemoveInstanceOneToOneNatRequest\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x1f\n\x17network_interface_index\x18\x02 \x01(\t\x12\x18\n\x10internal_address\x18\x03 \x01(\t\"8\n!RemoveInstanceOneToOneNatMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\"\xe5\x02\n%UpdateInstanceNetworkInterfaceRequest\x12\x19\n\x0binstance_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12%\n\x17network_interface_index\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x11\n\tsubnet_id\x18\x04 \x01(\t\x12L\n\x17primary_v4_address_spec\x18\x05 \x01(\x0b\x32+.yandex.cloud.compute.v1.PrimaryAddressSpec\x12L\n\x17primary_v6_address_spec\x18\x06 \x01(\x0b\x32+.yandex.cloud.compute.v1.PrimaryAddressSpec\x12\x1a\n\x12security_group_ids\x18\x07 \x03(\t\"^\n&UpdateInstanceNetworkInterfaceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x1f\n\x17network_interface_index\x18\x02 \x01(\t\"\x80\x01\n\x1dListInstanceOperationsRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"p\n\x1eListInstanceOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe7\x01\n\rResourcesSpec\x12&\n\x06memory\x18\x01 \x01(\x03\x42\x16\xe8\xc7\x31\x01\xfa\xc7\x31\x0e<=274877906944\x12i\n\x05\x63ores\x18\x02 \x01(\x03\x42Z\xe8\xc7\x31\x01\xfa\xc7\x31R2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,40,44,48,52,56,60,64,68,72,76,80\x12(\n\rcore_fraction\x18\x03 \x01(\x03\x42\x11\xfa\xc7\x31\r0,5,20,50,100\x12\x19\n\x04gpus\x18\x04 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30,1,2,4\"\x98\x05\n\x10\x41ttachedDiskSpec\x12<\n\x04mode\x18\x01 \x01(\x0e\x32..yandex.cloud.compute.v1.AttachedDiskSpec.Mode\x12-\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\x18\xf2\xc7\x31\x14[a-z][a-z0-9-_]{,19}\x12\x13\n\x0b\x61uto_delete\x18\x03 \x01(\x08\x12G\n\tdisk_spec\x18\x04 \x01(\x0b\x32\x32.yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpecH\x00\x12\x1b\n\x07\x64isk_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x1a\xd0\x02\n\x08\x44iskSpec\x12\x32\n\x04name\x18\x01 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x19\n\x07type_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12+\n\x04size\x18\x04 \x01(\x03\x42\x1d\xe8\xc7\x31\x01\xfa\xc7\x31\x15\x34\x31\x39\x34\x33\x30\x34-4398046511104\x12\x12\n\nblock_size\x18\x08 \x01(\x03\x12K\n\x15\x64isk_placement_policy\x18\x07 \x01(\x0b\x32,.yandex.cloud.compute.v1.DiskPlacementPolicy\x12\x1c\n\x08image_id\x18\x05 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x12\x1f\n\x0bsnapshot_id\x18\x06 \x01(\tB\x08\x8a\xc8\x31\x04<=50H\x00\x42\x08\n\x06source\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\x42\x0c\n\x04\x64isk\x12\x04\xc0\xc1\x31\x01\"+\n\x15\x41ttachedLocalDiskSpec\x12\x12\n\x04size\x18\x01 \x01(\x03\x42\x04\xe8\xc7\x31\x01\"\xe9\x01\n\x16\x41ttachedFilesystemSpec\x12\x42\n\x04mode\x18\x01 \x01(\x0e\x32\x34.yandex.cloud.compute.v1.AttachedFilesystemSpec.Mode\x12-\n\x0b\x64\x65vice_name\x18\x02 \x01(\tB\x18\xf2\xc7\x31\x14[a-z][a-z0-9-_]{,19}\x12\x1f\n\rfilesystem_id\x18\x03 \x01(\tB\x08\x8a\xc8\x31\x04<=50\";\n\x04Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\r\n\tREAD_ONLY\x10\x01\x12\x0e\n\nREAD_WRITE\x10\x02\"\xef\x01\n\x14NetworkInterfaceSpec\x12\x1f\n\tsubnet_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12L\n\x17primary_v4_address_spec\x18\x02 \x01(\x0b\x32+.yandex.cloud.compute.v1.PrimaryAddressSpec\x12L\n\x17primary_v6_address_spec\x18\x03 \x01(\x0b\x32+.yandex.cloud.compute.v1.PrimaryAddressSpec\x12\x1a\n\x12security_group_ids\x18\x06 \x03(\t\"\xae\x01\n\x12PrimaryAddressSpec\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x45\n\x13one_to_one_nat_spec\x18\x02 \x01(\x0b\x32(.yandex.cloud.compute.v1.OneToOneNatSpec\x12@\n\x10\x64ns_record_specs\x18\x03 \x03(\x0b\x32&.yandex.cloud.compute.v1.DnsRecordSpec\"\x9c\x01\n\x0fOneToOneNatSpec\x12\x36\n\nip_version\x18\x01 \x01(\x0e\x32\".yandex.cloud.compute.v1.IpVersion\x12\x0f\n\x07\x61\x64\x64ress\x18\x02 \x01(\t\x12@\n\x10\x64ns_record_specs\x18\x03 \x03(\x0b\x32&.yandex.cloud.compute.v1.DnsRecordSpec\"_\n\rDnsRecordSpec\x12\x12\n\x04\x66qdn\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x13\n\x0b\x64ns_zone_id\x18\x02 \x01(\t\x12\x18\n\x03ttl\x18\x03 \x01(\x03\x42\x0b\xfa\xc7\x31\x07\x30-86400\x12\x0b\n\x03ptr\x18\x04 \x01(\x08\"e\n\x13MoveInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"d\n\x14MoveInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x18\n\x10source_folder_id\x18\x02 \x01(\t\x12\x1d\n\x15\x64\x65stination_folder_id\x18\x03 \x01(\t\"g\n\x17RelocateInstanceRequest\x12!\n\x0binstance_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x13\x64\x65stination_zone_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"d\n\x18RelocateInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\x12\x16\n\x0esource_zone_id\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x65stination_zone_id\x18\x03 \x01(\t\"0\n\x19GuestStopInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\".\n\x17PreemptInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t\",\n\x15\x43rashInstanceMetadata\x12\x13\n\x0binstance_id\x18\x01 \x01(\t*#\n\x0cInstanceView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x32\xe6\x1e\n\x0fInstanceService\x12\x82\x01\n\x03Get\x12+.yandex.cloud.compute.v1.GetInstanceRequest\x1a!.yandex.cloud.compute.v1.Instance\"+\x82\xd3\xe4\x93\x02%\x12#/compute/v1/instances/{instance_id}\x12\x84\x01\n\x04List\x12-.yandex.cloud.compute.v1.ListInstancesRequest\x1a..yandex.cloud.compute.v1.ListInstancesResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/compute/v1/instances\x12\xa3\x01\n\x06\x43reate\x12..yandex.cloud.compute.v1.CreateInstanceRequest\x1a!.yandex.cloud.operation.Operation\"F\x82\xd3\xe4\x93\x02\x1a\"\x15/compute/v1/instances:\x01*\xb2\xd2*\"\n\x16\x43reateInstanceMetadata\x12\x08Instance\x12\xb1\x01\n\x06Update\x12..yandex.cloud.compute.v1.UpdateInstanceRequest\x1a!.yandex.cloud.operation.Operation\"T\x82\xd3\xe4\x93\x02(2#/compute/v1/instances/{instance_id}:\x01*\xb2\xd2*\"\n\x16UpdateInstanceMetadata\x12\x08Instance\x12\xbb\x01\n\x06\x44\x65lete\x12..yandex.cloud.compute.v1.DeleteInstanceRequest\x1a!.yandex.cloud.operation.Operation\"^\x82\xd3\xe4\x93\x02%*#/compute/v1/instances/{instance_id}\xb2\xd2*/\n\x16\x44\x65leteInstanceMetadata\x12\x15google.protobuf.Empty\x12\xd8\x01\n\x0eUpdateMetadata\x12\x36.yandex.cloud.compute.v1.UpdateInstanceMetadataRequest\x1a!.yandex.cloud.operation.Operation\"k\x82\xd3\xe4\x93\x02\x37\"2/compute/v1/instances/{instance_id}/updateMetadata:\x01*\xb2\xd2**\n\x1eUpdateInstanceMetadataMetadata\x12\x08Instance\x12\xce\x01\n\x13GetSerialPortOutput\x12;.yandex.cloud.compute.v1.GetInstanceSerialPortOutputRequest\x1a<.yandex.cloud.compute.v1.GetInstanceSerialPortOutputResponse\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/compute/v1/instances/{instance_id}:serialPortOutput\x12\xba\x01\n\x04Stop\x12,.yandex.cloud.compute.v1.StopInstanceRequest\x1a!.yandex.cloud.operation.Operation\"a\x82\xd3\xe4\x93\x02*\"(/compute/v1/instances/{instance_id}:stop\xb2\xd2*-\n\x14StopInstanceMetadata\x12\x15google.protobuf.Empty\x12\xb1\x01\n\x05Start\x12-.yandex.cloud.compute.v1.StartInstanceRequest\x1a!.yandex.cloud.operation.Operation\"V\x82\xd3\xe4\x93\x02+\")/compute/v1/instances/{instance_id}:start\xb2\xd2*!\n\x15StartInstanceMetadata\x12\x08Instance\x12\xc6\x01\n\x07Restart\x12/.yandex.cloud.compute.v1.RestartInstanceRequest\x1a!.yandex.cloud.operation.Operation\"g\x82\xd3\xe4\x93\x02-\"+/compute/v1/instances/{instance_id}:restart\xb2\xd2*0\n\x17RestartInstanceMetadata\x12\x15google.protobuf.Empty\x12\xc8\x01\n\nAttachDisk\x12\x32.yandex.cloud.compute.v1.AttachInstanceDiskRequest\x1a!.yandex.cloud.operation.Operation\"c\x82\xd3\xe4\x93\x02\x33\"./compute/v1/instances/{instance_id}:attachDisk:\x01*\xb2\xd2*&\n\x1a\x41ttachInstanceDiskMetadata\x12\x08Instance\x12\xc8\x01\n\nDetachDisk\x12\x32.yandex.cloud.compute.v1.DetachInstanceDiskRequest\x1a!.yandex.cloud.operation.Operation\"c\x82\xd3\xe4\x93\x02\x33\"./compute/v1/instances/{instance_id}:detachDisk:\x01*\xb2\xd2*&\n\x1a\x44\x65tachInstanceDiskMetadata\x12\x08Instance\x12\xe0\x01\n\x10\x41ttachFilesystem\x12\x38.yandex.cloud.compute.v1.AttachInstanceFilesystemRequest\x1a!.yandex.cloud.operation.Operation\"o\x82\xd3\xe4\x93\x02\x39\"4/compute/v1/instances/{instance_id}:attachFilesystem:\x01*\xb2\xd2*,\n AttachInstanceFilesystemMetadata\x12\x08Instance\x12\xe0\x01\n\x10\x44\x65tachFilesystem\x12\x38.yandex.cloud.compute.v1.DetachInstanceFilesystemRequest\x1a!.yandex.cloud.operation.Operation\"o\x82\xd3\xe4\x93\x02\x39\"4/compute/v1/instances/{instance_id}:detachFilesystem:\x01*\xb2\xd2*,\n DetachInstanceFilesystemMetadata\x12\x08Instance\x12\xd8\x01\n\x0e\x41\x64\x64OneToOneNat\x12\x36.yandex.cloud.compute.v1.AddInstanceOneToOneNatRequest\x1a!.yandex.cloud.operation.Operation\"k\x82\xd3\xe4\x93\x02\x37\"2/compute/v1/instances/{instance_id}/addOneToOneNat:\x01*\xb2\xd2**\n\x1e\x41\x64\x64InstanceOneToOneNatMetadata\x12\x08Instance\x12\xe4\x01\n\x11RemoveOneToOneNat\x12\x39.yandex.cloud.compute.v1.RemoveInstanceOneToOneNatRequest\x1a!.yandex.cloud.operation.Operation\"q\x82\xd3\xe4\x93\x02:\"5/compute/v1/instances/{instance_id}/removeOneToOneNat:\x01*\xb2\xd2*-\n!RemoveInstanceOneToOneNatMetadata\x12\x08Instance\x12\xf8\x01\n\x16UpdateNetworkInterface\x12>.yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceRequest\x1a!.yandex.cloud.operation.Operation\"{\x82\xd3\xe4\x93\x02?2:/compute/v1/instances/{instance_id}/updateNetworkInterface:\x01*\xb2\xd2*2\n&UpdateInstanceNetworkInterfaceMetadata\x12\x08Instance\x12\xb9\x01\n\x0eListOperations\x12\x36.yandex.cloud.compute.v1.ListInstanceOperationsRequest\x1a\x37.yandex.cloud.compute.v1.ListInstanceOperationsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./compute/v1/instances/{instance_id}/operations\x12\xb0\x01\n\x04Move\x12,.yandex.cloud.compute.v1.MoveInstanceRequest\x1a!.yandex.cloud.operation.Operation\"W\x82\xd3\xe4\x93\x02-\"(/compute/v1/instances/{instance_id}:move:\x01*\xb2\xd2* \n\x14MoveInstanceMetadata\x12\x08Instance\x12\xc0\x01\n\x08Relocate\x12\x30.yandex.cloud.compute.v1.RelocateInstanceRequest\x1a!.yandex.cloud.operation.Operation\"_\x82\xd3\xe4\x93\x02\x31\",/compute/v1/instances/{instance_id}:relocate:\x01*\xb2\xd2*$\n\x18RelocateInstanceMetadata\x12\x08InstanceBb\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2.DESCRIPTOR,yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_INSTANCEVIEW = _descriptor.EnumDescriptor(
  name='InstanceView',
  full_name='yandex.cloud.compute.v1.InstanceView',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASIC', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=8395,
  serialized_end=8430,
)
_sym_db.RegisterEnumDescriptor(_INSTANCEVIEW)

InstanceView = enum_type_wrapper.EnumTypeWrapper(_INSTANCEVIEW)
BASIC = 0
FULL = 1


_ATTACHEDDISKSPEC_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='yandex.cloud.compute.v1.AttachedDiskSpec.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_WRITE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6808,
  serialized_end=6867,
)
_sym_db.RegisterEnumDescriptor(_ATTACHEDDISKSPEC_MODE)

_ATTACHEDFILESYSTEMSPEC_MODE = _descriptor.EnumDescriptor(
  name='Mode',
  full_name='yandex.cloud.compute.v1.AttachedFilesystemSpec.Mode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_ONLY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='READ_WRITE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=6808,
  serialized_end=6867,
)
_sym_db.RegisterEnumDescriptor(_ATTACHEDFILESYSTEMSPEC_MODE)


_GETINSTANCEREQUEST = _descriptor.Descriptor(
  name='GetInstanceRequest',
  full_name='yandex.cloud.compute.v1.GetInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.GetInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view', full_name='yandex.cloud.compute.v1.GetInstanceRequest.view', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=428,
)


_LISTINSTANCESREQUEST = _descriptor.Descriptor(
  name='ListInstancesRequest',
  full_name='yandex.cloud.compute.v1.ListInstancesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.ListInstancesRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListInstancesRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListInstancesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.compute.v1.ListInstancesRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=431,
  serialized_end=576,
)


_LISTINSTANCESRESPONSE = _descriptor.Descriptor(
  name='ListInstancesResponse',
  full_name='yandex.cloud.compute.v1.ListInstancesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instances', full_name='yandex.cloud.compute.v1.ListInstancesResponse.instances', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListInstancesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=578,
  serialized_end=680,
)


_CREATEINSTANCEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.CreateInstanceRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1992,
  serialized_end=2037,
)

_CREATEINSTANCEREQUEST_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='yandex.cloud.compute.v1.CreateInstanceRequest.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2039,
  serialized_end=2086,
)

_CREATEINSTANCEREQUEST = _descriptor.Descriptor(
  name='CreateInstanceRequest',
  full_name='yandex.cloud.compute.v1.CreateInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_id', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.zone_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform_id', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.platform_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources_spec', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.resources_spec', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.metadata', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_options', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.metadata_options', index=8,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boot_disk_spec', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.boot_disk_spec', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secondary_disk_specs', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.secondary_disk_specs', index=10,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\003<=3', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='local_disk_specs', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.local_disk_specs', index=11,
      number=18, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesystem_specs', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.filesystem_specs', index=12,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_interface_specs', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.network_interface_specs', index=13,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\0011', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.hostname', index=14,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheduling_policy', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.scheduling_policy', index=15,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.service_account_id', index=16,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_settings', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.network_settings', index=17,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpu_settings', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.gpu_settings', index=18,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_policy', full_name='yandex.cloud.compute.v1.CreateInstanceRequest.placement_policy', index=19,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEINSTANCEREQUEST_LABELSENTRY, _CREATEINSTANCEREQUEST_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=683,
  serialized_end=2086,
)


_CREATEINSTANCEMETADATA = _descriptor.Descriptor(
  name='CreateInstanceMetadata',
  full_name='yandex.cloud.compute.v1.CreateInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.CreateInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2088,
  serialized_end=2143,
)


_UPDATEINSTANCEREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1992,
  serialized_end=2037,
)

_UPDATEINSTANCEREQUEST_METADATAENTRY = _descriptor.Descriptor(
  name='MetadataEntry',
  full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.MetadataEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.MetadataEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.MetadataEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2039,
  serialized_end=2086,
)

_UPDATEINSTANCEREQUEST = _descriptor.Descriptor(
  name='UpdateInstanceRequest',
  full_name='yandex.cloud.compute.v1.UpdateInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='platform_id', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.platform_id', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resources_spec', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.resources_spec', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.metadata', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='metadata_options', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.metadata_options', index=8,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.service_account_id', index=9,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_settings', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.network_settings', index=10,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='placement_policy', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.placement_policy', index=11,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scheduling_policy', full_name='yandex.cloud.compute.v1.UpdateInstanceRequest.scheduling_policy', index=12,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEINSTANCEREQUEST_LABELSENTRY, _UPDATEINSTANCEREQUEST_METADATAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2146,
  serialized_end=3050,
)


_UPDATEINSTANCEMETADATA = _descriptor.Descriptor(
  name='UpdateInstanceMetadata',
  full_name='yandex.cloud.compute.v1.UpdateInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.UpdateInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3052,
  serialized_end=3097,
)


_DELETEINSTANCEREQUEST = _descriptor.Descriptor(
  name='DeleteInstanceRequest',
  full_name='yandex.cloud.compute.v1.DeleteInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.DeleteInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3099,
  serialized_end=3157,
)


_DELETEINSTANCEMETADATA = _descriptor.Descriptor(
  name='DeleteInstanceMetadata',
  full_name='yandex.cloud.compute.v1.DeleteInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.DeleteInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3159,
  serialized_end=3204,
)


_UPDATEINSTANCEMETADATAREQUEST_UPSERTENTRY = _descriptor.Descriptor(
  name='UpsertEntry',
  full_name='yandex.cloud.compute.v1.UpdateInstanceMetadataRequest.UpsertEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.compute.v1.UpdateInstanceMetadataRequest.UpsertEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.compute.v1.UpdateInstanceMetadataRequest.UpsertEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3361,
  serialized_end=3406,
)

_UPDATEINSTANCEMETADATAREQUEST = _descriptor.Descriptor(
  name='UpdateInstanceMetadataRequest',
  full_name='yandex.cloud.compute.v1.UpdateInstanceMetadataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.UpdateInstanceMetadataRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delete', full_name='yandex.cloud.compute.v1.UpdateInstanceMetadataRequest.delete', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upsert', full_name='yandex.cloud.compute.v1.UpdateInstanceMetadataRequest.upsert', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEINSTANCEMETADATAREQUEST_UPSERTENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3207,
  serialized_end=3406,
)


_UPDATEINSTANCEMETADATAMETADATA = _descriptor.Descriptor(
  name='UpdateInstanceMetadataMetadata',
  full_name='yandex.cloud.compute.v1.UpdateInstanceMetadataMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.UpdateInstanceMetadataMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3408,
  serialized_end=3461,
)


_GETINSTANCESERIALPORTOUTPUTREQUEST = _descriptor.Descriptor(
  name='GetInstanceSerialPortOutputRequest',
  full_name='yandex.cloud.compute.v1.GetInstanceSerialPortOutputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.GetInstanceSerialPortOutputRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='yandex.cloud.compute.v1.GetInstanceSerialPortOutputRequest.port', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0071,2,3,4', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3463,
  serialized_end=3561,
)


_GETINSTANCESERIALPORTOUTPUTRESPONSE = _descriptor.Descriptor(
  name='GetInstanceSerialPortOutputResponse',
  full_name='yandex.cloud.compute.v1.GetInstanceSerialPortOutputResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='contents', full_name='yandex.cloud.compute.v1.GetInstanceSerialPortOutputResponse.contents', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3563,
  serialized_end=3618,
)


_STOPINSTANCEREQUEST = _descriptor.Descriptor(
  name='StopInstanceRequest',
  full_name='yandex.cloud.compute.v1.StopInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.StopInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3620,
  serialized_end=3676,
)


_STOPINSTANCEMETADATA = _descriptor.Descriptor(
  name='StopInstanceMetadata',
  full_name='yandex.cloud.compute.v1.StopInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.StopInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3678,
  serialized_end=3721,
)


_STARTINSTANCEREQUEST = _descriptor.Descriptor(
  name='StartInstanceRequest',
  full_name='yandex.cloud.compute.v1.StartInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.StartInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3723,
  serialized_end=3780,
)


_STARTINSTANCEMETADATA = _descriptor.Descriptor(
  name='StartInstanceMetadata',
  full_name='yandex.cloud.compute.v1.StartInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.StartInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3782,
  serialized_end=3826,
)


_RESTARTINSTANCEREQUEST = _descriptor.Descriptor(
  name='RestartInstanceRequest',
  full_name='yandex.cloud.compute.v1.RestartInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.RestartInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3828,
  serialized_end=3887,
)


_RESTARTINSTANCEMETADATA = _descriptor.Descriptor(
  name='RestartInstanceMetadata',
  full_name='yandex.cloud.compute.v1.RestartInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.RestartInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3889,
  serialized_end=3935,
)


_ATTACHINSTANCEDISKREQUEST = _descriptor.Descriptor(
  name='AttachInstanceDiskRequest',
  full_name='yandex.cloud.compute.v1.AttachInstanceDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.AttachInstanceDiskRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached_disk_spec', full_name='yandex.cloud.compute.v1.AttachInstanceDiskRequest.attached_disk_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3938,
  serialized_end=4077,
)


_ATTACHINSTANCEDISKMETADATA = _descriptor.Descriptor(
  name='AttachInstanceDiskMetadata',
  full_name='yandex.cloud.compute.v1.AttachInstanceDiskMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.AttachInstanceDiskMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.AttachInstanceDiskMetadata.disk_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4079,
  serialized_end=4145,
)


_DETACHINSTANCEDISKREQUEST = _descriptor.Descriptor(
  name='DetachInstanceDiskRequest',
  full_name='yandex.cloud.compute.v1.DetachInstanceDiskRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.DetachInstanceDiskRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.DetachInstanceDiskRequest.disk_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='yandex.cloud.compute.v1.DetachInstanceDiskRequest.device_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\024[a-z][a-z0-9-_]{,19}', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='disk', full_name='yandex.cloud.compute.v1.DetachInstanceDiskRequest.disk',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=4148,
  serialized_end=4302,
)


_DETACHINSTANCEDISKMETADATA = _descriptor.Descriptor(
  name='DetachInstanceDiskMetadata',
  full_name='yandex.cloud.compute.v1.DetachInstanceDiskMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.DetachInstanceDiskMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.DetachInstanceDiskMetadata.disk_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4304,
  serialized_end=4370,
)


_ATTACHINSTANCEFILESYSTEMREQUEST = _descriptor.Descriptor(
  name='AttachInstanceFilesystemRequest',
  full_name='yandex.cloud.compute.v1.AttachInstanceFilesystemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.AttachInstanceFilesystemRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='attached_filesystem_spec', full_name='yandex.cloud.compute.v1.AttachInstanceFilesystemRequest.attached_filesystem_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4373,
  serialized_end=4530,
)


_ATTACHINSTANCEFILESYSTEMMETADATA = _descriptor.Descriptor(
  name='AttachInstanceFilesystemMetadata',
  full_name='yandex.cloud.compute.v1.AttachInstanceFilesystemMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.AttachInstanceFilesystemMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesystem_id', full_name='yandex.cloud.compute.v1.AttachInstanceFilesystemMetadata.filesystem_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4532,
  serialized_end=4610,
)


_DETACHINSTANCEFILESYSTEMREQUEST = _descriptor.Descriptor(
  name='DetachInstanceFilesystemRequest',
  full_name='yandex.cloud.compute.v1.DetachInstanceFilesystemRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.DetachInstanceFilesystemRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesystem_id', full_name='yandex.cloud.compute.v1.DetachInstanceFilesystemRequest.filesystem_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='yandex.cloud.compute.v1.DetachInstanceFilesystemRequest.device_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\024[a-z][a-z0-9-_]{,19}', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='filesystem', full_name='yandex.cloud.compute.v1.DetachInstanceFilesystemRequest.filesystem',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=4613,
  serialized_end=4785,
)


_DETACHINSTANCEFILESYSTEMMETADATA = _descriptor.Descriptor(
  name='DetachInstanceFilesystemMetadata',
  full_name='yandex.cloud.compute.v1.DetachInstanceFilesystemMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.DetachInstanceFilesystemMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesystem_id', full_name='yandex.cloud.compute.v1.DetachInstanceFilesystemMetadata.filesystem_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4787,
  serialized_end=4865,
)


_ADDINSTANCEONETOONENATREQUEST = _descriptor.Descriptor(
  name='AddInstanceOneToOneNatRequest',
  full_name='yandex.cloud.compute.v1.AddInstanceOneToOneNatRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.AddInstanceOneToOneNatRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_interface_index', full_name='yandex.cloud.compute.v1.AddInstanceOneToOneNatRequest.network_interface_index', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_address', full_name='yandex.cloud.compute.v1.AddInstanceOneToOneNatRequest.internal_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_to_one_nat_spec', full_name='yandex.cloud.compute.v1.AddInstanceOneToOneNatRequest.one_to_one_nat_spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4868,
  serialized_end=5050,
)


_ADDINSTANCEONETOONENATMETADATA = _descriptor.Descriptor(
  name='AddInstanceOneToOneNatMetadata',
  full_name='yandex.cloud.compute.v1.AddInstanceOneToOneNatMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.AddInstanceOneToOneNatMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5052,
  serialized_end=5105,
)


_REMOVEINSTANCEONETOONENATREQUEST = _descriptor.Descriptor(
  name='RemoveInstanceOneToOneNatRequest',
  full_name='yandex.cloud.compute.v1.RemoveInstanceOneToOneNatRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.RemoveInstanceOneToOneNatRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_interface_index', full_name='yandex.cloud.compute.v1.RemoveInstanceOneToOneNatRequest.network_interface_index', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='internal_address', full_name='yandex.cloud.compute.v1.RemoveInstanceOneToOneNatRequest.internal_address', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5107,
  serialized_end=5221,
)


_REMOVEINSTANCEONETOONENATMETADATA = _descriptor.Descriptor(
  name='RemoveInstanceOneToOneNatMetadata',
  full_name='yandex.cloud.compute.v1.RemoveInstanceOneToOneNatMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.RemoveInstanceOneToOneNatMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5223,
  serialized_end=5279,
)


_UPDATEINSTANCENETWORKINTERFACEREQUEST = _descriptor.Descriptor(
  name='UpdateInstanceNetworkInterfaceRequest',
  full_name='yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_interface_index', full_name='yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceRequest.network_interface_index', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceRequest.update_mask', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceRequest.subnet_id', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_v4_address_spec', full_name='yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceRequest.primary_v4_address_spec', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_v6_address_spec', full_name='yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceRequest.primary_v6_address_spec', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceRequest.security_group_ids', index=6,
      number=7, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5282,
  serialized_end=5639,
)


_UPDATEINSTANCENETWORKINTERFACEMETADATA = _descriptor.Descriptor(
  name='UpdateInstanceNetworkInterfaceMetadata',
  full_name='yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='network_interface_index', full_name='yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceMetadata.network_interface_index', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5641,
  serialized_end=5735,
)


_LISTINSTANCEOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListInstanceOperationsRequest',
  full_name='yandex.cloud.compute.v1.ListInstanceOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.ListInstanceOperationsRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.compute.v1.ListInstanceOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.compute.v1.ListInstanceOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5738,
  serialized_end=5866,
)


_LISTINSTANCEOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListInstanceOperationsResponse',
  full_name='yandex.cloud.compute.v1.ListInstanceOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.compute.v1.ListInstanceOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.compute.v1.ListInstanceOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5868,
  serialized_end=5980,
)


_RESOURCESSPEC = _descriptor.Descriptor(
  name='ResourcesSpec',
  full_name='yandex.cloud.compute.v1.ResourcesSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='memory', full_name='yandex.cloud.compute.v1.ResourcesSpec.memory', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\372\3071\016<=274877906944', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cores', full_name='yandex.cloud.compute.v1.ResourcesSpec.cores', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\372\3071R2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,40,44,48,52,56,60,64,68,72,76,80', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='core_fraction', full_name='yandex.cloud.compute.v1.ResourcesSpec.core_fraction', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\r0,5,20,50,100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gpus', full_name='yandex.cloud.compute.v1.ResourcesSpec.gpus', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070,1,2,4', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5983,
  serialized_end=6214,
)


_ATTACHEDDISKSPEC_DISKSPEC = _descriptor.Descriptor(
  name='DiskSpec',
  full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type_id', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.type_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.size', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\372\3071\0254194304-4398046511104', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='block_size', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.block_size', index=4,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_placement_policy', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.disk_placement_policy', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_id', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.image_id', index=6,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_id', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.snapshot_id', index=7,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec.source',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=6470,
  serialized_end=6806,
)

_ATTACHEDDISKSPEC = _descriptor.Descriptor(
  name='AttachedDiskSpec',
  full_name='yandex.cloud.compute.v1.AttachedDiskSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.device_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\024[a-z][a-z0-9-_]{,19}', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auto_delete', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.auto_delete', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_spec', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.disk_spec', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disk_id', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.disk_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ATTACHEDDISKSPEC_DISKSPEC, ],
  enum_types=[
    _ATTACHEDDISKSPEC_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='disk', full_name='yandex.cloud.compute.v1.AttachedDiskSpec.disk',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=6217,
  serialized_end=6881,
)


_ATTACHEDLOCALDISKSPEC = _descriptor.Descriptor(
  name='AttachedLocalDiskSpec',
  full_name='yandex.cloud.compute.v1.AttachedLocalDiskSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.compute.v1.AttachedLocalDiskSpec.size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6883,
  serialized_end=6926,
)


_ATTACHEDFILESYSTEMSPEC = _descriptor.Descriptor(
  name='AttachedFilesystemSpec',
  full_name='yandex.cloud.compute.v1.AttachedFilesystemSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='yandex.cloud.compute.v1.AttachedFilesystemSpec.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_name', full_name='yandex.cloud.compute.v1.AttachedFilesystemSpec.device_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\024[a-z][a-z0-9-_]{,19}', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filesystem_id', full_name='yandex.cloud.compute.v1.AttachedFilesystemSpec.filesystem_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ATTACHEDFILESYSTEMSPEC_MODE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6929,
  serialized_end=7162,
)


_NETWORKINTERFACESPEC = _descriptor.Descriptor(
  name='NetworkInterfaceSpec',
  full_name='yandex.cloud.compute.v1.NetworkInterfaceSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='subnet_id', full_name='yandex.cloud.compute.v1.NetworkInterfaceSpec.subnet_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_v4_address_spec', full_name='yandex.cloud.compute.v1.NetworkInterfaceSpec.primary_v4_address_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='primary_v6_address_spec', full_name='yandex.cloud.compute.v1.NetworkInterfaceSpec.primary_v6_address_spec', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security_group_ids', full_name='yandex.cloud.compute.v1.NetworkInterfaceSpec.security_group_ids', index=3,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7165,
  serialized_end=7404,
)


_PRIMARYADDRESSSPEC = _descriptor.Descriptor(
  name='PrimaryAddressSpec',
  full_name='yandex.cloud.compute.v1.PrimaryAddressSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.compute.v1.PrimaryAddressSpec.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='one_to_one_nat_spec', full_name='yandex.cloud.compute.v1.PrimaryAddressSpec.one_to_one_nat_spec', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_record_specs', full_name='yandex.cloud.compute.v1.PrimaryAddressSpec.dns_record_specs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7407,
  serialized_end=7581,
)


_ONETOONENATSPEC = _descriptor.Descriptor(
  name='OneToOneNatSpec',
  full_name='yandex.cloud.compute.v1.OneToOneNatSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip_version', full_name='yandex.cloud.compute.v1.OneToOneNatSpec.ip_version', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='address', full_name='yandex.cloud.compute.v1.OneToOneNatSpec.address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_record_specs', full_name='yandex.cloud.compute.v1.OneToOneNatSpec.dns_record_specs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7584,
  serialized_end=7740,
)


_DNSRECORDSPEC = _descriptor.Descriptor(
  name='DnsRecordSpec',
  full_name='yandex.cloud.compute.v1.DnsRecordSpec',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fqdn', full_name='yandex.cloud.compute.v1.DnsRecordSpec.fqdn', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_zone_id', full_name='yandex.cloud.compute.v1.DnsRecordSpec.dns_zone_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ttl', full_name='yandex.cloud.compute.v1.DnsRecordSpec.ttl', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0070-86400', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ptr', full_name='yandex.cloud.compute.v1.DnsRecordSpec.ptr', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7742,
  serialized_end=7837,
)


_MOVEINSTANCEREQUEST = _descriptor.Descriptor(
  name='MoveInstanceRequest',
  full_name='yandex.cloud.compute.v1.MoveInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.MoveInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.compute.v1.MoveInstanceRequest.destination_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7839,
  serialized_end=7940,
)


_MOVEINSTANCEMETADATA = _descriptor.Descriptor(
  name='MoveInstanceMetadata',
  full_name='yandex.cloud.compute.v1.MoveInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.MoveInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_folder_id', full_name='yandex.cloud.compute.v1.MoveInstanceMetadata.source_folder_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_folder_id', full_name='yandex.cloud.compute.v1.MoveInstanceMetadata.destination_folder_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7942,
  serialized_end=8042,
)


_RELOCATEINSTANCEREQUEST = _descriptor.Descriptor(
  name='RelocateInstanceRequest',
  full_name='yandex.cloud.compute.v1.RelocateInstanceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.RelocateInstanceRequest.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_zone_id', full_name='yandex.cloud.compute.v1.RelocateInstanceRequest.destination_zone_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8044,
  serialized_end=8147,
)


_RELOCATEINSTANCEMETADATA = _descriptor.Descriptor(
  name='RelocateInstanceMetadata',
  full_name='yandex.cloud.compute.v1.RelocateInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.RelocateInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_zone_id', full_name='yandex.cloud.compute.v1.RelocateInstanceMetadata.source_zone_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='destination_zone_id', full_name='yandex.cloud.compute.v1.RelocateInstanceMetadata.destination_zone_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8149,
  serialized_end=8249,
)


_GUESTSTOPINSTANCEMETADATA = _descriptor.Descriptor(
  name='GuestStopInstanceMetadata',
  full_name='yandex.cloud.compute.v1.GuestStopInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.GuestStopInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8251,
  serialized_end=8299,
)


_PREEMPTINSTANCEMETADATA = _descriptor.Descriptor(
  name='PreemptInstanceMetadata',
  full_name='yandex.cloud.compute.v1.PreemptInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.PreemptInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8301,
  serialized_end=8347,
)


_CRASHINSTANCEMETADATA = _descriptor.Descriptor(
  name='CrashInstanceMetadata',
  full_name='yandex.cloud.compute.v1.CrashInstanceMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance_id', full_name='yandex.cloud.compute.v1.CrashInstanceMetadata.instance_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8349,
  serialized_end=8393,
)

_GETINSTANCEREQUEST.fields_by_name['view'].enum_type = _INSTANCEVIEW
_LISTINSTANCESRESPONSE.fields_by_name['instances'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._INSTANCE
_CREATEINSTANCEREQUEST_LABELSENTRY.containing_type = _CREATEINSTANCEREQUEST
_CREATEINSTANCEREQUEST_METADATAENTRY.containing_type = _CREATEINSTANCEREQUEST
_CREATEINSTANCEREQUEST.fields_by_name['labels'].message_type = _CREATEINSTANCEREQUEST_LABELSENTRY
_CREATEINSTANCEREQUEST.fields_by_name['resources_spec'].message_type = _RESOURCESSPEC
_CREATEINSTANCEREQUEST.fields_by_name['metadata'].message_type = _CREATEINSTANCEREQUEST_METADATAENTRY
_CREATEINSTANCEREQUEST.fields_by_name['metadata_options'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._METADATAOPTIONS
_CREATEINSTANCEREQUEST.fields_by_name['boot_disk_spec'].message_type = _ATTACHEDDISKSPEC
_CREATEINSTANCEREQUEST.fields_by_name['secondary_disk_specs'].message_type = _ATTACHEDDISKSPEC
_CREATEINSTANCEREQUEST.fields_by_name['local_disk_specs'].message_type = _ATTACHEDLOCALDISKSPEC
_CREATEINSTANCEREQUEST.fields_by_name['filesystem_specs'].message_type = _ATTACHEDFILESYSTEMSPEC
_CREATEINSTANCEREQUEST.fields_by_name['network_interface_specs'].message_type = _NETWORKINTERFACESPEC
_CREATEINSTANCEREQUEST.fields_by_name['scheduling_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._SCHEDULINGPOLICY
_CREATEINSTANCEREQUEST.fields_by_name['network_settings'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._NETWORKSETTINGS
_CREATEINSTANCEREQUEST.fields_by_name['gpu_settings'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._GPUSETTINGS
_CREATEINSTANCEREQUEST.fields_by_name['placement_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._PLACEMENTPOLICY
_UPDATEINSTANCEREQUEST_LABELSENTRY.containing_type = _UPDATEINSTANCEREQUEST
_UPDATEINSTANCEREQUEST_METADATAENTRY.containing_type = _UPDATEINSTANCEREQUEST
_UPDATEINSTANCEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEINSTANCEREQUEST.fields_by_name['labels'].message_type = _UPDATEINSTANCEREQUEST_LABELSENTRY
_UPDATEINSTANCEREQUEST.fields_by_name['resources_spec'].message_type = _RESOURCESSPEC
_UPDATEINSTANCEREQUEST.fields_by_name['metadata'].message_type = _UPDATEINSTANCEREQUEST_METADATAENTRY
_UPDATEINSTANCEREQUEST.fields_by_name['metadata_options'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._METADATAOPTIONS
_UPDATEINSTANCEREQUEST.fields_by_name['network_settings'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._NETWORKSETTINGS
_UPDATEINSTANCEREQUEST.fields_by_name['placement_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._PLACEMENTPOLICY
_UPDATEINSTANCEREQUEST.fields_by_name['scheduling_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._SCHEDULINGPOLICY
_UPDATEINSTANCEMETADATAREQUEST_UPSERTENTRY.containing_type = _UPDATEINSTANCEMETADATAREQUEST
_UPDATEINSTANCEMETADATAREQUEST.fields_by_name['upsert'].message_type = _UPDATEINSTANCEMETADATAREQUEST_UPSERTENTRY
_ATTACHINSTANCEDISKREQUEST.fields_by_name['attached_disk_spec'].message_type = _ATTACHEDDISKSPEC
_DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk'].fields.append(
  _DETACHINSTANCEDISKREQUEST.fields_by_name['disk_id'])
_DETACHINSTANCEDISKREQUEST.fields_by_name['disk_id'].containing_oneof = _DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk']
_DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk'].fields.append(
  _DETACHINSTANCEDISKREQUEST.fields_by_name['device_name'])
_DETACHINSTANCEDISKREQUEST.fields_by_name['device_name'].containing_oneof = _DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk']
_ATTACHINSTANCEFILESYSTEMREQUEST.fields_by_name['attached_filesystem_spec'].message_type = _ATTACHEDFILESYSTEMSPEC
_DETACHINSTANCEFILESYSTEMREQUEST.oneofs_by_name['filesystem'].fields.append(
  _DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['filesystem_id'])
_DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['filesystem_id'].containing_oneof = _DETACHINSTANCEFILESYSTEMREQUEST.oneofs_by_name['filesystem']
_DETACHINSTANCEFILESYSTEMREQUEST.oneofs_by_name['filesystem'].fields.append(
  _DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['device_name'])
_DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['device_name'].containing_oneof = _DETACHINSTANCEFILESYSTEMREQUEST.oneofs_by_name['filesystem']
_ADDINSTANCEONETOONENATREQUEST.fields_by_name['one_to_one_nat_spec'].message_type = _ONETOONENATSPEC
_UPDATEINSTANCENETWORKINTERFACEREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEINSTANCENETWORKINTERFACEREQUEST.fields_by_name['primary_v4_address_spec'].message_type = _PRIMARYADDRESSSPEC
_UPDATEINSTANCENETWORKINTERFACEREQUEST.fields_by_name['primary_v6_address_spec'].message_type = _PRIMARYADDRESSSPEC
_LISTINSTANCEOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['disk_placement_policy'].message_type = yandex_dot_cloud_dot_compute_dot_v1_dot_disk__pb2._DISKPLACEMENTPOLICY
_ATTACHEDDISKSPEC_DISKSPEC.containing_type = _ATTACHEDDISKSPEC
_ATTACHEDDISKSPEC_DISKSPEC.oneofs_by_name['source'].fields.append(
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['image_id'])
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['image_id'].containing_oneof = _ATTACHEDDISKSPEC_DISKSPEC.oneofs_by_name['source']
_ATTACHEDDISKSPEC_DISKSPEC.oneofs_by_name['source'].fields.append(
  _ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['snapshot_id'])
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['snapshot_id'].containing_oneof = _ATTACHEDDISKSPEC_DISKSPEC.oneofs_by_name['source']
_ATTACHEDDISKSPEC.fields_by_name['mode'].enum_type = _ATTACHEDDISKSPEC_MODE
_ATTACHEDDISKSPEC.fields_by_name['disk_spec'].message_type = _ATTACHEDDISKSPEC_DISKSPEC
_ATTACHEDDISKSPEC_MODE.containing_type = _ATTACHEDDISKSPEC
_ATTACHEDDISKSPEC.oneofs_by_name['disk'].fields.append(
  _ATTACHEDDISKSPEC.fields_by_name['disk_spec'])
_ATTACHEDDISKSPEC.fields_by_name['disk_spec'].containing_oneof = _ATTACHEDDISKSPEC.oneofs_by_name['disk']
_ATTACHEDDISKSPEC.oneofs_by_name['disk'].fields.append(
  _ATTACHEDDISKSPEC.fields_by_name['disk_id'])
_ATTACHEDDISKSPEC.fields_by_name['disk_id'].containing_oneof = _ATTACHEDDISKSPEC.oneofs_by_name['disk']
_ATTACHEDFILESYSTEMSPEC.fields_by_name['mode'].enum_type = _ATTACHEDFILESYSTEMSPEC_MODE
_ATTACHEDFILESYSTEMSPEC_MODE.containing_type = _ATTACHEDFILESYSTEMSPEC
_NETWORKINTERFACESPEC.fields_by_name['primary_v4_address_spec'].message_type = _PRIMARYADDRESSSPEC
_NETWORKINTERFACESPEC.fields_by_name['primary_v6_address_spec'].message_type = _PRIMARYADDRESSSPEC
_PRIMARYADDRESSSPEC.fields_by_name['one_to_one_nat_spec'].message_type = _ONETOONENATSPEC
_PRIMARYADDRESSSPEC.fields_by_name['dns_record_specs'].message_type = _DNSRECORDSPEC
_ONETOONENATSPEC.fields_by_name['ip_version'].enum_type = yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._IPVERSION
_ONETOONENATSPEC.fields_by_name['dns_record_specs'].message_type = _DNSRECORDSPEC
DESCRIPTOR.message_types_by_name['GetInstanceRequest'] = _GETINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['ListInstancesRequest'] = _LISTINSTANCESREQUEST
DESCRIPTOR.message_types_by_name['ListInstancesResponse'] = _LISTINSTANCESRESPONSE
DESCRIPTOR.message_types_by_name['CreateInstanceRequest'] = _CREATEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['CreateInstanceMetadata'] = _CREATEINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['UpdateInstanceRequest'] = _UPDATEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['UpdateInstanceMetadata'] = _UPDATEINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['DeleteInstanceRequest'] = _DELETEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['DeleteInstanceMetadata'] = _DELETEINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['UpdateInstanceMetadataRequest'] = _UPDATEINSTANCEMETADATAREQUEST
DESCRIPTOR.message_types_by_name['UpdateInstanceMetadataMetadata'] = _UPDATEINSTANCEMETADATAMETADATA
DESCRIPTOR.message_types_by_name['GetInstanceSerialPortOutputRequest'] = _GETINSTANCESERIALPORTOUTPUTREQUEST
DESCRIPTOR.message_types_by_name['GetInstanceSerialPortOutputResponse'] = _GETINSTANCESERIALPORTOUTPUTRESPONSE
DESCRIPTOR.message_types_by_name['StopInstanceRequest'] = _STOPINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['StopInstanceMetadata'] = _STOPINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['StartInstanceRequest'] = _STARTINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['StartInstanceMetadata'] = _STARTINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['RestartInstanceRequest'] = _RESTARTINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['RestartInstanceMetadata'] = _RESTARTINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['AttachInstanceDiskRequest'] = _ATTACHINSTANCEDISKREQUEST
DESCRIPTOR.message_types_by_name['AttachInstanceDiskMetadata'] = _ATTACHINSTANCEDISKMETADATA
DESCRIPTOR.message_types_by_name['DetachInstanceDiskRequest'] = _DETACHINSTANCEDISKREQUEST
DESCRIPTOR.message_types_by_name['DetachInstanceDiskMetadata'] = _DETACHINSTANCEDISKMETADATA
DESCRIPTOR.message_types_by_name['AttachInstanceFilesystemRequest'] = _ATTACHINSTANCEFILESYSTEMREQUEST
DESCRIPTOR.message_types_by_name['AttachInstanceFilesystemMetadata'] = _ATTACHINSTANCEFILESYSTEMMETADATA
DESCRIPTOR.message_types_by_name['DetachInstanceFilesystemRequest'] = _DETACHINSTANCEFILESYSTEMREQUEST
DESCRIPTOR.message_types_by_name['DetachInstanceFilesystemMetadata'] = _DETACHINSTANCEFILESYSTEMMETADATA
DESCRIPTOR.message_types_by_name['AddInstanceOneToOneNatRequest'] = _ADDINSTANCEONETOONENATREQUEST
DESCRIPTOR.message_types_by_name['AddInstanceOneToOneNatMetadata'] = _ADDINSTANCEONETOONENATMETADATA
DESCRIPTOR.message_types_by_name['RemoveInstanceOneToOneNatRequest'] = _REMOVEINSTANCEONETOONENATREQUEST
DESCRIPTOR.message_types_by_name['RemoveInstanceOneToOneNatMetadata'] = _REMOVEINSTANCEONETOONENATMETADATA
DESCRIPTOR.message_types_by_name['UpdateInstanceNetworkInterfaceRequest'] = _UPDATEINSTANCENETWORKINTERFACEREQUEST
DESCRIPTOR.message_types_by_name['UpdateInstanceNetworkInterfaceMetadata'] = _UPDATEINSTANCENETWORKINTERFACEMETADATA
DESCRIPTOR.message_types_by_name['ListInstanceOperationsRequest'] = _LISTINSTANCEOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListInstanceOperationsResponse'] = _LISTINSTANCEOPERATIONSRESPONSE
DESCRIPTOR.message_types_by_name['ResourcesSpec'] = _RESOURCESSPEC
DESCRIPTOR.message_types_by_name['AttachedDiskSpec'] = _ATTACHEDDISKSPEC
DESCRIPTOR.message_types_by_name['AttachedLocalDiskSpec'] = _ATTACHEDLOCALDISKSPEC
DESCRIPTOR.message_types_by_name['AttachedFilesystemSpec'] = _ATTACHEDFILESYSTEMSPEC
DESCRIPTOR.message_types_by_name['NetworkInterfaceSpec'] = _NETWORKINTERFACESPEC
DESCRIPTOR.message_types_by_name['PrimaryAddressSpec'] = _PRIMARYADDRESSSPEC
DESCRIPTOR.message_types_by_name['OneToOneNatSpec'] = _ONETOONENATSPEC
DESCRIPTOR.message_types_by_name['DnsRecordSpec'] = _DNSRECORDSPEC
DESCRIPTOR.message_types_by_name['MoveInstanceRequest'] = _MOVEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['MoveInstanceMetadata'] = _MOVEINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['RelocateInstanceRequest'] = _RELOCATEINSTANCEREQUEST
DESCRIPTOR.message_types_by_name['RelocateInstanceMetadata'] = _RELOCATEINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['GuestStopInstanceMetadata'] = _GUESTSTOPINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['PreemptInstanceMetadata'] = _PREEMPTINSTANCEMETADATA
DESCRIPTOR.message_types_by_name['CrashInstanceMetadata'] = _CRASHINSTANCEMETADATA
DESCRIPTOR.enum_types_by_name['InstanceView'] = _INSTANCEVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetInstanceRequest = _reflection.GeneratedProtocolMessageType('GetInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetInstanceRequest)
  })
_sym_db.RegisterMessage(GetInstanceRequest)

ListInstancesRequest = _reflection.GeneratedProtocolMessageType('ListInstancesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCESREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListInstancesRequest)
  })
_sym_db.RegisterMessage(ListInstancesRequest)

ListInstancesResponse = _reflection.GeneratedProtocolMessageType('ListInstancesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCESRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListInstancesResponse)
  })
_sym_db.RegisterMessage(ListInstancesResponse)

CreateInstanceRequest = _reflection.GeneratedProtocolMessageType('CreateInstanceRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEINSTANCEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateInstanceRequest.LabelsEntry)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEINSTANCEREQUEST_METADATAENTRY,
    '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateInstanceRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEINSTANCEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateInstanceRequest)
  })
_sym_db.RegisterMessage(CreateInstanceRequest)
_sym_db.RegisterMessage(CreateInstanceRequest.LabelsEntry)
_sym_db.RegisterMessage(CreateInstanceRequest.MetadataEntry)

CreateInstanceMetadata = _reflection.GeneratedProtocolMessageType('CreateInstanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEINSTANCEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CreateInstanceMetadata)
  })
_sym_db.RegisterMessage(CreateInstanceMetadata)

UpdateInstanceRequest = _reflection.GeneratedProtocolMessageType('UpdateInstanceRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEINSTANCEREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceRequest.LabelsEntry)
    })
  ,

  'MetadataEntry' : _reflection.GeneratedProtocolMessageType('MetadataEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEINSTANCEREQUEST_METADATAENTRY,
    '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceRequest.MetadataEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEINSTANCEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceRequest)
  })
_sym_db.RegisterMessage(UpdateInstanceRequest)
_sym_db.RegisterMessage(UpdateInstanceRequest.LabelsEntry)
_sym_db.RegisterMessage(UpdateInstanceRequest.MetadataEntry)

UpdateInstanceMetadata = _reflection.GeneratedProtocolMessageType('UpdateInstanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINSTANCEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceMetadata)
  })
_sym_db.RegisterMessage(UpdateInstanceMetadata)

DeleteInstanceRequest = _reflection.GeneratedProtocolMessageType('DeleteInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEINSTANCEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteInstanceRequest)
  })
_sym_db.RegisterMessage(DeleteInstanceRequest)

DeleteInstanceMetadata = _reflection.GeneratedProtocolMessageType('DeleteInstanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEINSTANCEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DeleteInstanceMetadata)
  })
_sym_db.RegisterMessage(DeleteInstanceMetadata)

UpdateInstanceMetadataRequest = _reflection.GeneratedProtocolMessageType('UpdateInstanceMetadataRequest', (_message.Message,), {

  'UpsertEntry' : _reflection.GeneratedProtocolMessageType('UpsertEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEINSTANCEMETADATAREQUEST_UPSERTENTRY,
    '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceMetadataRequest.UpsertEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEINSTANCEMETADATAREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceMetadataRequest)
  })
_sym_db.RegisterMessage(UpdateInstanceMetadataRequest)
_sym_db.RegisterMessage(UpdateInstanceMetadataRequest.UpsertEntry)

UpdateInstanceMetadataMetadata = _reflection.GeneratedProtocolMessageType('UpdateInstanceMetadataMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINSTANCEMETADATAMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceMetadataMetadata)
  })
_sym_db.RegisterMessage(UpdateInstanceMetadataMetadata)

GetInstanceSerialPortOutputRequest = _reflection.GeneratedProtocolMessageType('GetInstanceSerialPortOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCESERIALPORTOUTPUTREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetInstanceSerialPortOutputRequest)
  })
_sym_db.RegisterMessage(GetInstanceSerialPortOutputRequest)

GetInstanceSerialPortOutputResponse = _reflection.GeneratedProtocolMessageType('GetInstanceSerialPortOutputResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINSTANCESERIALPORTOUTPUTRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GetInstanceSerialPortOutputResponse)
  })
_sym_db.RegisterMessage(GetInstanceSerialPortOutputResponse)

StopInstanceRequest = _reflection.GeneratedProtocolMessageType('StopInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOPINSTANCEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.StopInstanceRequest)
  })
_sym_db.RegisterMessage(StopInstanceRequest)

StopInstanceMetadata = _reflection.GeneratedProtocolMessageType('StopInstanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STOPINSTANCEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.StopInstanceMetadata)
  })
_sym_db.RegisterMessage(StopInstanceMetadata)

StartInstanceRequest = _reflection.GeneratedProtocolMessageType('StartInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTINSTANCEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.StartInstanceRequest)
  })
_sym_db.RegisterMessage(StartInstanceRequest)

StartInstanceMetadata = _reflection.GeneratedProtocolMessageType('StartInstanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _STARTINSTANCEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.StartInstanceMetadata)
  })
_sym_db.RegisterMessage(StartInstanceMetadata)

RestartInstanceRequest = _reflection.GeneratedProtocolMessageType('RestartInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTINSTANCEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.RestartInstanceRequest)
  })
_sym_db.RegisterMessage(RestartInstanceRequest)

RestartInstanceMetadata = _reflection.GeneratedProtocolMessageType('RestartInstanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RESTARTINSTANCEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.RestartInstanceMetadata)
  })
_sym_db.RegisterMessage(RestartInstanceMetadata)

AttachInstanceDiskRequest = _reflection.GeneratedProtocolMessageType('AttachInstanceDiskRequest', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHINSTANCEDISKREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AttachInstanceDiskRequest)
  })
_sym_db.RegisterMessage(AttachInstanceDiskRequest)

AttachInstanceDiskMetadata = _reflection.GeneratedProtocolMessageType('AttachInstanceDiskMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHINSTANCEDISKMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AttachInstanceDiskMetadata)
  })
_sym_db.RegisterMessage(AttachInstanceDiskMetadata)

DetachInstanceDiskRequest = _reflection.GeneratedProtocolMessageType('DetachInstanceDiskRequest', (_message.Message,), {
  'DESCRIPTOR' : _DETACHINSTANCEDISKREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DetachInstanceDiskRequest)
  })
_sym_db.RegisterMessage(DetachInstanceDiskRequest)

DetachInstanceDiskMetadata = _reflection.GeneratedProtocolMessageType('DetachInstanceDiskMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DETACHINSTANCEDISKMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DetachInstanceDiskMetadata)
  })
_sym_db.RegisterMessage(DetachInstanceDiskMetadata)

AttachInstanceFilesystemRequest = _reflection.GeneratedProtocolMessageType('AttachInstanceFilesystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHINSTANCEFILESYSTEMREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AttachInstanceFilesystemRequest)
  })
_sym_db.RegisterMessage(AttachInstanceFilesystemRequest)

AttachInstanceFilesystemMetadata = _reflection.GeneratedProtocolMessageType('AttachInstanceFilesystemMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHINSTANCEFILESYSTEMMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AttachInstanceFilesystemMetadata)
  })
_sym_db.RegisterMessage(AttachInstanceFilesystemMetadata)

DetachInstanceFilesystemRequest = _reflection.GeneratedProtocolMessageType('DetachInstanceFilesystemRequest', (_message.Message,), {
  'DESCRIPTOR' : _DETACHINSTANCEFILESYSTEMREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DetachInstanceFilesystemRequest)
  })
_sym_db.RegisterMessage(DetachInstanceFilesystemRequest)

DetachInstanceFilesystemMetadata = _reflection.GeneratedProtocolMessageType('DetachInstanceFilesystemMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DETACHINSTANCEFILESYSTEMMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DetachInstanceFilesystemMetadata)
  })
_sym_db.RegisterMessage(DetachInstanceFilesystemMetadata)

AddInstanceOneToOneNatRequest = _reflection.GeneratedProtocolMessageType('AddInstanceOneToOneNatRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDINSTANCEONETOONENATREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AddInstanceOneToOneNatRequest)
  })
_sym_db.RegisterMessage(AddInstanceOneToOneNatRequest)

AddInstanceOneToOneNatMetadata = _reflection.GeneratedProtocolMessageType('AddInstanceOneToOneNatMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDINSTANCEONETOONENATMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AddInstanceOneToOneNatMetadata)
  })
_sym_db.RegisterMessage(AddInstanceOneToOneNatMetadata)

RemoveInstanceOneToOneNatRequest = _reflection.GeneratedProtocolMessageType('RemoveInstanceOneToOneNatRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEINSTANCEONETOONENATREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.RemoveInstanceOneToOneNatRequest)
  })
_sym_db.RegisterMessage(RemoveInstanceOneToOneNatRequest)

RemoveInstanceOneToOneNatMetadata = _reflection.GeneratedProtocolMessageType('RemoveInstanceOneToOneNatMetadata', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEINSTANCEONETOONENATMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.RemoveInstanceOneToOneNatMetadata)
  })
_sym_db.RegisterMessage(RemoveInstanceOneToOneNatMetadata)

UpdateInstanceNetworkInterfaceRequest = _reflection.GeneratedProtocolMessageType('UpdateInstanceNetworkInterfaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINSTANCENETWORKINTERFACEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceRequest)
  })
_sym_db.RegisterMessage(UpdateInstanceNetworkInterfaceRequest)

UpdateInstanceNetworkInterfaceMetadata = _reflection.GeneratedProtocolMessageType('UpdateInstanceNetworkInterfaceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEINSTANCENETWORKINTERFACEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.UpdateInstanceNetworkInterfaceMetadata)
  })
_sym_db.RegisterMessage(UpdateInstanceNetworkInterfaceMetadata)

ListInstanceOperationsRequest = _reflection.GeneratedProtocolMessageType('ListInstanceOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCEOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListInstanceOperationsRequest)
  })
_sym_db.RegisterMessage(ListInstanceOperationsRequest)

ListInstanceOperationsResponse = _reflection.GeneratedProtocolMessageType('ListInstanceOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTINSTANCEOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ListInstanceOperationsResponse)
  })
_sym_db.RegisterMessage(ListInstanceOperationsResponse)

ResourcesSpec = _reflection.GeneratedProtocolMessageType('ResourcesSpec', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.ResourcesSpec)
  })
_sym_db.RegisterMessage(ResourcesSpec)

AttachedDiskSpec = _reflection.GeneratedProtocolMessageType('AttachedDiskSpec', (_message.Message,), {

  'DiskSpec' : _reflection.GeneratedProtocolMessageType('DiskSpec', (_message.Message,), {
    'DESCRIPTOR' : _ATTACHEDDISKSPEC_DISKSPEC,
    '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AttachedDiskSpec.DiskSpec)
    })
  ,
  'DESCRIPTOR' : _ATTACHEDDISKSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AttachedDiskSpec)
  })
_sym_db.RegisterMessage(AttachedDiskSpec)
_sym_db.RegisterMessage(AttachedDiskSpec.DiskSpec)

AttachedLocalDiskSpec = _reflection.GeneratedProtocolMessageType('AttachedLocalDiskSpec', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHEDLOCALDISKSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AttachedLocalDiskSpec)
  })
_sym_db.RegisterMessage(AttachedLocalDiskSpec)

AttachedFilesystemSpec = _reflection.GeneratedProtocolMessageType('AttachedFilesystemSpec', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHEDFILESYSTEMSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.AttachedFilesystemSpec)
  })
_sym_db.RegisterMessage(AttachedFilesystemSpec)

NetworkInterfaceSpec = _reflection.GeneratedProtocolMessageType('NetworkInterfaceSpec', (_message.Message,), {
  'DESCRIPTOR' : _NETWORKINTERFACESPEC,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.NetworkInterfaceSpec)
  })
_sym_db.RegisterMessage(NetworkInterfaceSpec)

PrimaryAddressSpec = _reflection.GeneratedProtocolMessageType('PrimaryAddressSpec', (_message.Message,), {
  'DESCRIPTOR' : _PRIMARYADDRESSSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.PrimaryAddressSpec)
  })
_sym_db.RegisterMessage(PrimaryAddressSpec)

OneToOneNatSpec = _reflection.GeneratedProtocolMessageType('OneToOneNatSpec', (_message.Message,), {
  'DESCRIPTOR' : _ONETOONENATSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.OneToOneNatSpec)
  })
_sym_db.RegisterMessage(OneToOneNatSpec)

DnsRecordSpec = _reflection.GeneratedProtocolMessageType('DnsRecordSpec', (_message.Message,), {
  'DESCRIPTOR' : _DNSRECORDSPEC,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.DnsRecordSpec)
  })
_sym_db.RegisterMessage(DnsRecordSpec)

MoveInstanceRequest = _reflection.GeneratedProtocolMessageType('MoveInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEINSTANCEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.MoveInstanceRequest)
  })
_sym_db.RegisterMessage(MoveInstanceRequest)

MoveInstanceMetadata = _reflection.GeneratedProtocolMessageType('MoveInstanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _MOVEINSTANCEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.MoveInstanceMetadata)
  })
_sym_db.RegisterMessage(MoveInstanceMetadata)

RelocateInstanceRequest = _reflection.GeneratedProtocolMessageType('RelocateInstanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _RELOCATEINSTANCEREQUEST,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.RelocateInstanceRequest)
  })
_sym_db.RegisterMessage(RelocateInstanceRequest)

RelocateInstanceMetadata = _reflection.GeneratedProtocolMessageType('RelocateInstanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _RELOCATEINSTANCEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.RelocateInstanceMetadata)
  })
_sym_db.RegisterMessage(RelocateInstanceMetadata)

GuestStopInstanceMetadata = _reflection.GeneratedProtocolMessageType('GuestStopInstanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _GUESTSTOPINSTANCEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.GuestStopInstanceMetadata)
  })
_sym_db.RegisterMessage(GuestStopInstanceMetadata)

PreemptInstanceMetadata = _reflection.GeneratedProtocolMessageType('PreemptInstanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _PREEMPTINSTANCEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.PreemptInstanceMetadata)
  })
_sym_db.RegisterMessage(PreemptInstanceMetadata)

CrashInstanceMetadata = _reflection.GeneratedProtocolMessageType('CrashInstanceMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CRASHINSTANCEMETADATA,
  '__module__' : 'yandex.cloud.compute.v1.instance_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.CrashInstanceMetadata)
  })
_sym_db.RegisterMessage(CrashInstanceMetadata)


DESCRIPTOR._options = None
_GETINSTANCEREQUEST.fields_by_name['instance_id']._options = None
_LISTINSTANCESREQUEST.fields_by_name['folder_id']._options = None
_LISTINSTANCESREQUEST.fields_by_name['page_size']._options = None
_LISTINSTANCESREQUEST.fields_by_name['page_token']._options = None
_LISTINSTANCESREQUEST.fields_by_name['filter']._options = None
_CREATEINSTANCEREQUEST_LABELSENTRY._options = None
_CREATEINSTANCEREQUEST_METADATAENTRY._options = None
_CREATEINSTANCEREQUEST.fields_by_name['folder_id']._options = None
_CREATEINSTANCEREQUEST.fields_by_name['name']._options = None
_CREATEINSTANCEREQUEST.fields_by_name['description']._options = None
_CREATEINSTANCEREQUEST.fields_by_name['labels']._options = None
_CREATEINSTANCEREQUEST.fields_by_name['zone_id']._options = None
_CREATEINSTANCEREQUEST.fields_by_name['platform_id']._options = None
_CREATEINSTANCEREQUEST.fields_by_name['resources_spec']._options = None
_CREATEINSTANCEREQUEST.fields_by_name['boot_disk_spec']._options = None
_CREATEINSTANCEREQUEST.fields_by_name['secondary_disk_specs']._options = None
_CREATEINSTANCEREQUEST.fields_by_name['network_interface_specs']._options = None
_CREATEINSTANCEREQUEST.fields_by_name['hostname']._options = None
_CREATEINSTANCEMETADATA.fields_by_name['instance_id']._options = None
_UPDATEINSTANCEREQUEST_LABELSENTRY._options = None
_UPDATEINSTANCEREQUEST_METADATAENTRY._options = None
_UPDATEINSTANCEREQUEST.fields_by_name['instance_id']._options = None
_UPDATEINSTANCEREQUEST.fields_by_name['name']._options = None
_UPDATEINSTANCEREQUEST.fields_by_name['description']._options = None
_UPDATEINSTANCEREQUEST.fields_by_name['labels']._options = None
_DELETEINSTANCEREQUEST.fields_by_name['instance_id']._options = None
_UPDATEINSTANCEMETADATAREQUEST_UPSERTENTRY._options = None
_GETINSTANCESERIALPORTOUTPUTREQUEST.fields_by_name['instance_id']._options = None
_GETINSTANCESERIALPORTOUTPUTREQUEST.fields_by_name['port']._options = None
_STOPINSTANCEREQUEST.fields_by_name['instance_id']._options = None
_STARTINSTANCEREQUEST.fields_by_name['instance_id']._options = None
_RESTARTINSTANCEREQUEST.fields_by_name['instance_id']._options = None
_ATTACHINSTANCEDISKREQUEST.fields_by_name['instance_id']._options = None
_ATTACHINSTANCEDISKREQUEST.fields_by_name['attached_disk_spec']._options = None
_DETACHINSTANCEDISKREQUEST.oneofs_by_name['disk']._options = None
_DETACHINSTANCEDISKREQUEST.fields_by_name['instance_id']._options = None
_DETACHINSTANCEDISKREQUEST.fields_by_name['disk_id']._options = None
_DETACHINSTANCEDISKREQUEST.fields_by_name['device_name']._options = None
_ATTACHINSTANCEFILESYSTEMREQUEST.fields_by_name['instance_id']._options = None
_ATTACHINSTANCEFILESYSTEMREQUEST.fields_by_name['attached_filesystem_spec']._options = None
_DETACHINSTANCEFILESYSTEMREQUEST.oneofs_by_name['filesystem']._options = None
_DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['instance_id']._options = None
_DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['filesystem_id']._options = None
_DETACHINSTANCEFILESYSTEMREQUEST.fields_by_name['device_name']._options = None
_UPDATEINSTANCENETWORKINTERFACEREQUEST.fields_by_name['instance_id']._options = None
_UPDATEINSTANCENETWORKINTERFACEREQUEST.fields_by_name['network_interface_index']._options = None
_LISTINSTANCEOPERATIONSREQUEST.fields_by_name['instance_id']._options = None
_LISTINSTANCEOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTINSTANCEOPERATIONSREQUEST.fields_by_name['page_token']._options = None
_RESOURCESSPEC.fields_by_name['memory']._options = None
_RESOURCESSPEC.fields_by_name['cores']._options = None
_RESOURCESSPEC.fields_by_name['core_fraction']._options = None
_RESOURCESSPEC.fields_by_name['gpus']._options = None
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['name']._options = None
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['description']._options = None
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['type_id']._options = None
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['size']._options = None
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['image_id']._options = None
_ATTACHEDDISKSPEC_DISKSPEC.fields_by_name['snapshot_id']._options = None
_ATTACHEDDISKSPEC.oneofs_by_name['disk']._options = None
_ATTACHEDDISKSPEC.fields_by_name['device_name']._options = None
_ATTACHEDDISKSPEC.fields_by_name['disk_id']._options = None
_ATTACHEDLOCALDISKSPEC.fields_by_name['size']._options = None
_ATTACHEDFILESYSTEMSPEC.fields_by_name['device_name']._options = None
_ATTACHEDFILESYSTEMSPEC.fields_by_name['filesystem_id']._options = None
_NETWORKINTERFACESPEC.fields_by_name['subnet_id']._options = None
_DNSRECORDSPEC.fields_by_name['fqdn']._options = None
_DNSRECORDSPEC.fields_by_name['ttl']._options = None
_MOVEINSTANCEREQUEST.fields_by_name['instance_id']._options = None
_MOVEINSTANCEREQUEST.fields_by_name['destination_folder_id']._options = None
_RELOCATEINSTANCEREQUEST.fields_by_name['instance_id']._options = None
_RELOCATEINSTANCEREQUEST.fields_by_name['destination_zone_id']._options = None

_INSTANCESERVICE = _descriptor.ServiceDescriptor(
  name='InstanceService',
  full_name='yandex.cloud.compute.v1.InstanceService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=8433,
  serialized_end=12375,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.compute.v1.InstanceService.Get',
    index=0,
    containing_service=None,
    input_type=_GETINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2._INSTANCE,
    serialized_options=b'\202\323\344\223\002%\022#/compute/v1/instances/{instance_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.compute.v1.InstanceService.List',
    index=1,
    containing_service=None,
    input_type=_LISTINSTANCESREQUEST,
    output_type=_LISTINSTANCESRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/compute/v1/instances',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.compute.v1.InstanceService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002\032\"\025/compute/v1/instances:\001*\262\322*\"\n\026CreateInstanceMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.compute.v1.InstanceService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002(2#/compute/v1/instances/{instance_id}:\001*\262\322*\"\n\026UpdateInstanceMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.compute.v1.InstanceService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002%*#/compute/v1/instances/{instance_id}\262\322*/\n\026DeleteInstanceMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateMetadata',
    full_name='yandex.cloud.compute.v1.InstanceService.UpdateMetadata',
    index=5,
    containing_service=None,
    input_type=_UPDATEINSTANCEMETADATAREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0027\"2/compute/v1/instances/{instance_id}/updateMetadata:\001*\262\322**\n\036UpdateInstanceMetadataMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetSerialPortOutput',
    full_name='yandex.cloud.compute.v1.InstanceService.GetSerialPortOutput',
    index=6,
    containing_service=None,
    input_type=_GETINSTANCESERIALPORTOUTPUTREQUEST,
    output_type=_GETINSTANCESERIALPORTOUTPUTRESPONSE,
    serialized_options=b'\202\323\344\223\0026\0224/compute/v1/instances/{instance_id}:serialPortOutput',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Stop',
    full_name='yandex.cloud.compute.v1.InstanceService.Stop',
    index=7,
    containing_service=None,
    input_type=_STOPINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002*\"(/compute/v1/instances/{instance_id}:stop\262\322*-\n\024StopInstanceMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Start',
    full_name='yandex.cloud.compute.v1.InstanceService.Start',
    index=8,
    containing_service=None,
    input_type=_STARTINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002+\")/compute/v1/instances/{instance_id}:start\262\322*!\n\025StartInstanceMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Restart',
    full_name='yandex.cloud.compute.v1.InstanceService.Restart',
    index=9,
    containing_service=None,
    input_type=_RESTARTINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002-\"+/compute/v1/instances/{instance_id}:restart\262\322*0\n\027RestartInstanceMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AttachDisk',
    full_name='yandex.cloud.compute.v1.InstanceService.AttachDisk',
    index=10,
    containing_service=None,
    input_type=_ATTACHINSTANCEDISKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0023\"./compute/v1/instances/{instance_id}:attachDisk:\001*\262\322*&\n\032AttachInstanceDiskMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DetachDisk',
    full_name='yandex.cloud.compute.v1.InstanceService.DetachDisk',
    index=11,
    containing_service=None,
    input_type=_DETACHINSTANCEDISKREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0023\"./compute/v1/instances/{instance_id}:detachDisk:\001*\262\322*&\n\032DetachInstanceDiskMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AttachFilesystem',
    full_name='yandex.cloud.compute.v1.InstanceService.AttachFilesystem',
    index=12,
    containing_service=None,
    input_type=_ATTACHINSTANCEFILESYSTEMREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0029\"4/compute/v1/instances/{instance_id}:attachFilesystem:\001*\262\322*,\n AttachInstanceFilesystemMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DetachFilesystem',
    full_name='yandex.cloud.compute.v1.InstanceService.DetachFilesystem',
    index=13,
    containing_service=None,
    input_type=_DETACHINSTANCEFILESYSTEMREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0029\"4/compute/v1/instances/{instance_id}:detachFilesystem:\001*\262\322*,\n DetachInstanceFilesystemMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddOneToOneNat',
    full_name='yandex.cloud.compute.v1.InstanceService.AddOneToOneNat',
    index=14,
    containing_service=None,
    input_type=_ADDINSTANCEONETOONENATREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0027\"2/compute/v1/instances/{instance_id}/addOneToOneNat:\001*\262\322**\n\036AddInstanceOneToOneNatMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveOneToOneNat',
    full_name='yandex.cloud.compute.v1.InstanceService.RemoveOneToOneNat',
    index=15,
    containing_service=None,
    input_type=_REMOVEINSTANCEONETOONENATREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002:\"5/compute/v1/instances/{instance_id}/removeOneToOneNat:\001*\262\322*-\n!RemoveInstanceOneToOneNatMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateNetworkInterface',
    full_name='yandex.cloud.compute.v1.InstanceService.UpdateNetworkInterface',
    index=16,
    containing_service=None,
    input_type=_UPDATEINSTANCENETWORKINTERFACEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002?2:/compute/v1/instances/{instance_id}/updateNetworkInterface:\001*\262\322*2\n&UpdateInstanceNetworkInterfaceMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.compute.v1.InstanceService.ListOperations',
    index=17,
    containing_service=None,
    input_type=_LISTINSTANCEOPERATIONSREQUEST,
    output_type=_LISTINSTANCEOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\0020\022./compute/v1/instances/{instance_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Move',
    full_name='yandex.cloud.compute.v1.InstanceService.Move',
    index=18,
    containing_service=None,
    input_type=_MOVEINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002-\"(/compute/v1/instances/{instance_id}:move:\001*\262\322* \n\024MoveInstanceMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Relocate',
    full_name='yandex.cloud.compute.v1.InstanceService.Relocate',
    index=19,
    containing_service=None,
    input_type=_RELOCATEINSTANCEREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0021\",/compute/v1/instances/{instance_id}:relocate:\001*\262\322*$\n\030RelocateInstanceMetadata\022\010Instance',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_INSTANCESERVICE)

DESCRIPTOR.services_by_name['InstanceService'] = _INSTANCESERVICE

# @@protoc_insertion_point(module_scope)
